##  Discovery Suggestions for MCP Servers
In the discovery inbox, you get recommendations for linking discovered MCP servers to interface fact sheets.
Fact Sheet Type | Description | Example | Action Available
---|---|---|---
MCP server (subtype of interface) | MCP (Model Context Protocol) servers are managed communication endpoints that expose specific capabilities to AI applications or systems using standardized protocol interfaces. They act as intermediaries for data exchange and tool orchestration. | MCP server for SAP LeanIX | Create or link


